==> oddmuse-1.310.tar.gz: oddmuse-1.310/swedish-utf8.pl <==
# -*-mode: fundamental; coding: utf-8;-*-
# UTF-8 encoded Swedish language file for use with Oddmuse
#
# Copyright (c) 2003 Erik S-O Johansson and others
# Copyright (c) 2003 Björn Lindström <bkhl@elektrubadur.se> and
#                    Björn X Öqvist <zrajm@klingonska.org
# Copyright (c) 2004 Johan Adler <emacs deleted at Johan's request>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
# This file should be saved into the same folder where the config file
# resides.  Load it from the config file:
#
# do 'swedish-utf8.pl';
#
# This translation was last checked for OddMuse version 1.304.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Läsning inte tillåten: användare, ip eller nätverk är blockerat.
Could not create %s
Kunde inte skapa %s
Invalid UserName %s: not saved.
Ogiltigt användarnamn %s: Ej sparad.
UserName must be 50 characters or less: not saved
Användarnamn får bestå av högst 50 tecken: Ej sparad.
XML::RSS is not available on this system.

LWP::UserAgent is not available on this system.

diff
skillnad
history
historik
 . . . . 

Click to create this page
Klicka för att skapa denna sida
http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
alternativ
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
sök
Invalid action parameter %s
Ogiltig parameter %s
Invalid URL.
Ogiltig URL.
Page name is too long: %s
Sidnamn är för långt: %s
Invalid Page %s
Ogiltig sida %s
Invalid Page %s (must not end with .db)
Ogiltig sida %s (får inte sluta med .db) 
Invalid Page %s (must not end with .lck)
Ogiltig sida %s (får inte sluta med .lck) 
Page name may not contain space characters: %s
Sidans namn får inte innehålla mellanslag: %s
Preview:
Förhandsgranskning:
Preview only, not yet saved
Endast förhandsgranskning, ännu inte sparad
Please go on to %s.
Gå vidare till %s.
Could not open %s log file
Kunde inte öppna %s-loggen
Error was
Felet var
Note: This error is normal if no changes have been made.
Observera: Det här felet är normalt om inga ändringar gjorts.
Could not open old %s log file
Kunde inte öppna gammal %s-loggfil
No updates since %s
Inga ändringar sedan %s
Updates since %s
Ändringar sedan %s
Updates in the last %s days
Ändringar de %s senaste dagarna
Updates in the last %s day
Ändringar den %s senaste dagen
for %s only
endast för %s
List latest change per page only
Visa bara den senaste ändringen för varje sida
List only major changes
Visa bara stora ändringar
Include minor changes
Visa även små ändringar
List all changes
Visa alla ändringar
%s days
%s dagar
List later changes
Visa senare ändringar
Username:
Användarnamn:
Host:
Värd:
Language:
Språk
Filters
Filter
Go!
Sök
(minor)
(mindre)
rollback
återställning
from %s
från %s
History of %s
Historik för %s
Compare
Jämför
Revision %s
Version %s
by
av
Rolling back changes
Återställer
Missing target for rollback.
Mål för återställning saknas
Target for rollback is too far back.
Mål för återstållning för gammalt.
Rollback to %s
Återställning till %s
%s rolled back
%s återställd
[Home]
[Startsida]
redirected from %s
omdirigerad från %s
Click to search for references to this page

Cookie: 

new comment
ny kommentar
Save
Spara
Preview
Förhandsgranska
Comments on this page
Kommentarer till den här sidan
Edit revision %s of this page
Redigera version %s av den här sidan
Edit text of this page
Redigera den här sidan
This page is read-only
Den här sidan är skrivskyddad
View other revisions
Visa andra versioner
View current revision
Visa nuvarande version
View all changes
Visa alla ändringar
Back to %s
Tillbaka till %s
Last edited
Senast redigerad
Edited
Redigerad
by %s
av %s
(diff)
(ändringar)
Warning
Varning
Database is stored in temporary directory %s
Databas sparad i tillfällig katalog %s
%s seconds
%s sekunder
The same page on other sites:
Samma sida på andra siter:
EditNearLinks

Search:
Sökning:
Replace:
Ersätt:
Validate HTML
Validera HTML
Validate CSS
Validera CSS
Difference (from revision %1 to %2)
Skillnad (från version %1 till %2)
revision %s
version %s
current revision
nuvarande version
Difference (from prior %s revision)
Ändringar (sedan tidigare version %s)
major
stor
minor
liten
No diff available.
Ingen skillnad tillgänglig.
Changed:
Ändrad:
Removed:
Borttagen:
Added:
Tillagd:
to
till
Revision %s not available
Version %s inte tillgänglig
showing current revision instead
visar nuvarande version istället
Showing revision %s
Det här är version %s
Cannot save an nameless page.
Kan inte spara en namnlös sida.
Cannot open %s
Kan inte öppna %s
Cannot write %s
Kan inte skriva %s
Could not get %s lock
Kunde inte låsa %s
Unlocking
Låser upp
This operation may take several seconds...
Den här funktionen kan ta flera sekunder...
Forced unlock of %s lock.
Forcerad upplåsning av %s.
No unlock required.
Ingen upplåsning behövs.
%s hours ago
för %s timmar sedan
1 hour ago
för 1 timme sedan
%s minutes ago
%s minuter sedan
1 minute ago
1 minut sedan
%s seconds ago
%s sekunder sedan
1 second ago
1 sekund sedan
just now
just nu
Editing Denied
Redigering nekas
Editing not allowed: user, ip, or network is blocked.
Redigering inte tillåten: användare, ip-adress eller nätverk är blockerat.
Contact the wiki administrator for more information.
Kontakta wiki-administratören för mer information.
The rule %s matched for you.
Regeln %s passar in på dig.
See %s for more information.
Se %s för mer information.
Editing not allowed: %s is read-only.
Redigering är inte tillåten: %s är skrivskyddad.
Only administrators can upload files.
Bara administratörer kan ladda upp filer.
Editing revision %s of
Redigerar version %s av
Editing %s
Redigerar %s
Editing old revision %s.
Redigerar gammal version %s.
Saving this page will replace the latest revision with this text.
Att spara den här sidan kommer att ersätta den senaste versionen med den här texten.
Summary:
Sammanfattning:
This change is a minor edit.
Den här förändringen är en mindre ändring.
Replace this file with text.
Ersätt den här filen med text.
Replace this text with a file.
Ersätt den här texten med en fil.
File to upload: 
Fil att ladda upp:
Files of type %s are not allowed.
Filer av typen %s är inte tillåtna.
Password
Lösenord
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ditt lösenord sparas i en cookie, om du har cookies tillgängliga. Cookies kan försvinna om du ansluter från en annan dator, från ett annat konto, eller med annan programvara.
You are currently an administrator on this site.
Du är för närvarande administratör av den här webbplatsen.
You are currently an editor on this site.
Du är för närvarande redaktör på den här webbplatsen.
You are a normal user on this site.
Du är en normal användare på den här webbplatsen.
Your password does not match any of the  administrator or editor passwords.
Ditt lösenord motsvarar inget av admininistratörs- eller redaktörslösenorden.
Password:
Lösenord:
This site does not use admin or editor passwords.
Den här webbplatsen använder inte administratörs- eller redaktörslösenord.
This operation is restricted to site editors only...
Den här funktionen kan bara utföras av redaktörer...
This operation is restricted to administrators only...
Den här funktionen kan bara utföras av adminstratörer...
Index of all pages
Index över alla sidor
all pages
alla sidor
permanent anchors
permanenta ankare
near links
nära länkar
(for %s)
(för %s)
%s pages found.
%s sidor funna.
Replaced: %s
Ersatt: %s
Search for: %s
Sök efter: %s
View changes for these pages
Se ändringar för dessa sidor
Search sites on the %s as well
Sök siter på %s också
and
och
or
eller
Fetching results from %s:
Hämtar resultat från %s:
Near pages:
Nära sidor:
last updated
senast reviderad
Full Link List
Fullständing länklista
Complete Content
Fullständigt innehåll
The main page is %s.
Huvudsidan är %s.
Editing not allowed for %s.
%s kan inte redigeras.
SampleUndefinedPage
OdefinieradExempelsida
%s cannot be defined.
%s kan inte definieras.
Sample_Undefined_Page
Odefinierad_exempelsida
[[%s]] cannot be defined.
[[%s]] kan inte definieras.
Only an administrator can create %s
Bara en administratör can skapa %s
Transfer Error: %s
Överföringsfel: %s
Browser reports no file info.
Webbläsare rapporterar ingen filinformation.
Browser reports no file type.
Webbläsare rapporterar ingen filtyp.
This page was changed by somebody else %s.
Den här sidan ändrades av någon annan %s.
The changes conflict.  Please check the page again.
Ändringarna står i konflikt. Kontrollera sidan igen.
Please check whether you overwrote those changes.
Kontrollera om du skrev över de ändringarna.
Anonymous
Anonym
Could not get a lock to merge!
Kunde inte låsa för att slå samman!
you
du
ancestor
förfader
other
annan
Ping
Ping
No response.
Inget svar.
Maintenance on all pages
Underhåll av alla sidor
Maintenance not done.
Underhåll är inte färdigt.
(Maintenance can only be done once every 12 hours.)
(Underhåll kan bara utföras en gång var 12:e timme.)
Remove the "maintain" file or wait.
Ta bort filen "maintain" eller vänta
Main lock obtained.
Huvudlås påslaget.
Expiring keep files and deleting pages marked for deletion

deleted
borttagen
Moving part of the %s log file.
Flyttar del av %s-loggen
Moving %s log entries.
Flyttar %s loggnotering.
Getting page index file for %s.
Hämtar sidindexfil för %s.
Main lock released.
Huvudlås avslaget.
Set or Remove global edit lock
Slå på eller av globalt redigeringslås
Edit lock created.
Redigeringslås påslaget.
Edit lock removed.
Redigeringslås avslaget.
Set or Remove page edit lock
Slå på eller av sidredigeringslås
Missing page id to lock/unlock...
Saknar sid-id, kan inte slå på eller av redigeringslås...
Lock for %s created.
Slog på redigeringslås för %s.
Lock for %s removed.
Slog av redigeringslås för för %s.
Displaying Wiki Version
Visar Wikiversion
Inter links:
Interlänkar:
Near links:
Nära länkar:
Too many connections by %s
För många anslutningar ifrån %s
Recent Visitors
Senaste besökare
Referrers
Sidor som länkat hit
All Referrers
Alla som länkat hit
anchor first defined here: %s
ankare definierades här först: %s
Click to search for references to this permanent anchor
Klicka för att söka efter referenser till detta permanenta ankare
END_OF_TRANSLATION

==> oddmuse-1.437.tar.gz: oddmuse-1.437/swedish-utf8.pl <==
# -*-mode: fundamental; coding: utf-8;-*-
# UTF-8 encoded Swedish language file for use with Oddmuse
#
# Copyright (c) 2003 Erik S-O Johansson and others
# Copyright (c) 2003 Björn Lindström <bkhl@elektrubadur.se> and
#                    Zrajm C Akfohg <zrajm@klingonska.org>
# Copyright (c) 2004 Johan Adler <emacs deleted at Johan's request>
# Copyright (c) 2004 Zrajm C Akfohg <zrajm@klingonska.org
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for OddMuse version 1.304.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Läsning inte tillåten: användare, ip eller nätverk är blockerat.
Could not create %s
Kunde inte skapa %s
Invalid UserName %s: not saved.
Ogiltigt användarnamn %s: Ej sparad.
UserName must be 50 characters or less: not saved
Användarnamn får bestå av högst 50 tecken: Ej sparad.
XML::RSS is not available on this system.
XML::RSS r inte tillgngligt p det hr systemet.
diff
ändringar
history
historik
%s returned no data, or LWP::UserAgent is not available.
Antingen returnerade %s inget data, eller s finns inte LWP::UserAgent tillgngligt.
RSS parsing failed for %s
Misslyckades med RSS parsningen av %s
 . . . . 

Click to create this page
Klicka för att skapa den här sidan
http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
alternativ
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
sök
Invalid action parameter %s
Ogiltig parameter %s
Invalid URL.
Ogiltig URL.
Page name is missing
Sidnamn saknas
Page name is too long: %s
Sidnamn är för långt: %s
Invalid Page %s
Ogiltig sida %s
Invalid Page %s (must not end with .db)
Ogiltig sida %s (får inte sluta med .db) 
Invalid Page %s (must not end with .lck)
Ogiltig sida %s (får inte sluta med .lck) 
Page name may not contain space characters: %s
Sidans namn får inte innehålla mellanslag: %s
Preview:
Förhandsgranskning:
Preview only, not yet saved
Endast förhandsgranskning, ännu inte sparad
Please go on to %s.
Gå vidare till %s.
Could not open %s log file
Kunde inte öppna %s-loggen
Error was
Felet var
Note: This error is normal if no changes have been made.
Observera: Det här felet är normalt om inga ändringar gjorts.
Could not open old %s log file
Kunde inte öppna gammal %s-loggfil
No updates since %s
Inga ändringar sedan %s
Updates since %s
Ändringar sedan %s
Updates in the last %s days
Ändringar de %s senaste dagarna
Updates in the last %s day
Ändringar den %s senaste dagen
for %s only
för endast %s
List latest change per page only
Visa bara senaste ändring för varje sida
List all changes
Visa alla ändringar
List only major changes
Visa bara stora ändringar
Include minor changes
Visa små ändringar också
%s days
%s dagar
List later changes
Visa senare ändringar
Username:
Användare:
Host:
Värddator:
Language:
Språk
Filters
Sålla
Go!
Utför
(minor)
(mindre)
rollback
återställning
new

from %s
från %s
History of %s
Historik för %s
Compare
Jämför
Revision %s
Version %s
by
av
Rolling back changes
Återställer
Missing target for rollback.
Mål för återställning saknas
Target for rollback is too far back.
Mål för återstållning för gammalt.
Rollback to %s
Återställning till %s
%s rolled back
%s återställd
[Home]
[Startsida]
redirected from %s
omdirigerad från %s
Click to search for references to this page
Klicka för att söka efter referenser till den här sidan
Cookie: 
Cookie: 
Warning
Varning
Database is stored in temporary directory %s
Databas sparad i tillfällig katalog %s
%s seconds
%s sekunder
The same page on other sites:
Samma sida på andra siter:
EditNearLinks

Last edited
Senast ändrad
Edited
Redigerad
by %s
av %s
(diff)
(ändringar)
Run maintenance
Utför underhåll
Unlock site
Lås upp wikin
Lock site
Lås wikin
Unlock page
Lås upp sidan
Lock page
Lås sidan
Comments on this page
Kommentera sidan
Edit revision %s of this page
Redigera version %s av den här sidan
Edit text of this page
Redigera sidan
e
r
This page is read-only
Sidan är skrivskyddad
View other revisions
Visa andra versioner
View current revision
Visa rådande version
View all changes
Visa alla ändringar
Back to %s
Tillbaka till %s
new comment
ny kommentar
s
s
Save
Spara
Preview
Förhandsgranska
Search:
Sök:
Replace:
Ersätt:
Validate HTML
Validera HTML
Validate CSS
Validera CSS
Difference (from revision %1 to %2)
Skillnad (från version %1 till %2)
revision %s
version %s
current revision
rådande version
Difference (from prior %s revision)
Förändring (sedan senaste %s revidering)
major
stora
minor
mindre
No diff available.
Information om ändring är inte tillgänglig.
Changed:
Ändrad:
Removed:
Borttagen:
Added:
Tillagd:
to
till
Revision %s not available
Version %s inte tillgänglig
showing current revision instead
visar rådande version istället
Showing revision %s
Det här är version %s
Cannot save an nameless page.
Kan inte spara en namnlös sida.
Cannot open %s
Kan inte öppna %s
Cannot write %s
Kan inte skriva %s
Could not get %s lock
Kunde inte låsa %s
Unlocking
Låser upp
This operation may take several seconds...
Den här funktionen kan ta flera sekunder...
Forced unlock of %s lock.
Forcerad upplåsning av %s.
No unlock required.
Ingen upplåsning behövs.
%s hours ago
för %s timmar sedan
1 hour ago
för 1 timme sedan
%s minutes ago
%s minuter sedan
1 minute ago
1 minut sedan
%s seconds ago
%s sekunder sedan
1 second ago
1 sekund sedan
just now
just nu
Editing Denied
Redigering nekas
Editing not allowed: user, ip, or network is blocked.
Redigering inte tillåten: användare, ip-adress eller nätverk är blockerat.
Contact the wiki administrator for more information.
Kontakta wiki-administratören för mer information.
The rule %s matched for you.
Regeln %s passar in på dig.
See %s for more information.
Se %s för mer information.
Editing not allowed: %s is read-only.
Redigering är inte tillåten: %s är skrivskyddad.
Only administrators can upload files.
Bara administratörer kan ladda upp filer.
Editing revision %s of
Redigerar version %s av
Editing %s
Redigerar %s
Editing old revision %s.
Redigerar gammal version %s.
Saving this page will replace the latest revision with this text.
Att spara den här sidan kommer att ersätta den senaste versionen med den här texten.
Summary:
Sammanfattning:
This change is a minor edit.
Det här är en mindre ändring.
Replace this file with text.
Skriv text istället för den här filen.
Replace this text with a file.
Använd en fil i stället för den här texten.
File to upload: 
Fil att ladda upp:
Files of type %s are not allowed.
Filer av typen %s är inte tillåtna.
Password
Lösenord
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ditt lösenord sparas i en cookie om du har cookies påslagna. Cookies kan försvinna om du ansluter från en annan dator, från ett annat konto eller med ett annat program.
You are currently an administrator on this site.
Du är för närvarande administratör för den här webbplatsen.
You are currently an editor on this site.
Du är för närvarande redaktör för den här webbplatsen.
You are a normal user on this site.
Du är en normal användare på den här webbplatsen.
Your password does not match any of the  administrator or editor passwords.
Ditt lösenord motsvarar inget av admininistratörs- eller redaktörslösenorden.
Password:
Lösenord:
This site does not use admin or editor passwords.
Den här webbplatsen använder inte administratörs- eller redaktörslösenord.
This operation is restricted to site editors only...
Den här funktionen kan bara utföras av redaktörer...
This operation is restricted to administrators only...
Den här funktionen kan bara utföras av adminstratörer...
Index of all pages
Index över alla sidor
all pages
alla sidor
permanent anchors
permanenta ankare
near links
nära länkar
(for %s)
(för: %s)
%s pages found.
%s sidor.
Replaced: %s
Ersatt: %s
Search for: %s
Sök efter: %s
View changes for these pages
Se ändringar för dessa sidor
Search sites on the %s as well
Sök siter på %s också
and
och
or
eller
Fetching results from %s:
Hämtar resultat från %s:
Near pages:
Nära sidor:
last updated
senast reviderad
Complete Content
Fullständigt innehåll
The main page is %s.
Huvudsidan är %s.
Editing not allowed for %s.
%s kan inte redigeras.
SampleUndefinedPage
OdefinieradExempelsida
%s cannot be defined.
%s kan inte definieras.
Sample_Undefined_Page
Odefinierad_exempelsida
[[%s]] cannot be defined.
[[%s]] kan inte definieras.
Only an administrator can create %s.
Bara en administratör kan skapa %s.
Transfer Error: %s
Överföringsfel: %s
Browser reports no file info.
Webbläsare rapporterar ingen filinformation.
Browser reports no file type.
Webbläsare rapporterar ingen filtyp.
Edit Denied
Redigering nekas
The page contains banned text.
Sidan innehåller otillåten text.
This page was changed by somebody else %s.
Den här sidan ändrades av någon annan %s.
The changes conflict.  Please check the page again.
Ändringarna står i konflikt. Kontrollera sidan igen.
Please check whether you overwrote those changes.
Kontrollera om du skrev över de ändringarna.
Anonymous
Anonym
Could not get a lock to merge!
Kunde inte låsa för att slå samman!
you
du
ancestor
förfader
other
annan
Maintenance on all pages
Underhåll av alla sidor
Maintenance not done.
Underhåll ej slutfört.
(Maintenance can only be done once every 12 hours.)
(Underhåll kan bara utföras en gång var 12:e timme.)
Remove the "maintain" file or wait.
Ta bort "maintain"-filen eller vänta.
Main lock obtained.
Huvudlås påslaget.
Expiring keep files and deleting pages marked for deletion
Avlägsnar "keep"-filer och raderar sidor märkta för radering
not deleted: 

deleted
borttagen
Moving part of the %s log file.
Flyttar del av %s-loggen
Moving %s log entries.
Flyttar %s loggnotering.
Getting page index file for %s.
Hämtar sidindexfil för %s.
Main lock released.
Huvudlås avslaget.
Set or Remove global edit lock
Slå på eller av globalt redigeringslås
Edit lock created.
Redigeringslås påslaget.
Edit lock removed.
Redigeringslås avslaget.
Set or Remove page edit lock
Slå på eller av sidredigeringslås
Missing page id to lock/unlock...
Saknar sid-id, kan inte slå på eller av redigeringslås...
Lock for %s created.
Slog på redigeringslås för %s.
Lock for %s removed.
Slog av redigeringslås för för %s.
Displaying Wiki Version
Visar Wikiversion
Inter links:
Interlänkar:
Near links:
Nära länkar:
Too many connections by %s
För många anslutningar ifrån %s
Please do not fetch more than %1 pages in %2 seconds.

Recent Visitors
Senaste besökare
Referrers
Sidor som länkat hit
All Referrers
Alla som länkat hit
anchor first defined here: %s
ankare definierades här först: %s
Click to search for references to this permanent anchor
Klicka för att söka efter referenser till det här permanenta ankaret
the page %s also exists
sidan %s finns också
Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Delete page

Rename this page to:

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Calendar %s

Footnotes:

image: %s

Languages:

Show!

Define

Full Link List
Fullständing länklista
Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Portrait

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Blog

END_OF_TRANSLATION
